@@ -93,8 +93,13 @@ def _datastream(check_continue_func, host=HOST, port=PORT):
 			print 'ValueError while trying to decode JSON object. discarding JSON that caused the error'
 		if data:
 			# build dictionary
-			ddict = dict(zip(brain_parameters, _extract_tuple(data)))
-			yield ddict
+			if eSense in data and eegPower in data:
+				ddict = dict(zip(brain_parameters, _extract_tuple(data)))
+				yield ddict
+			elif blinkStrength in data:
+				yield {blinkStrength:data[blinkStrength]}
+			else:
+				continue
 		else:
 			continue
 	cs.close()
